AppStackMenuItem class

Constructors

AppStackMenuItem({required String label, required String location, required IconData icon, Widget itemBuilder(BuildContext context, bool active)?, int? badge, List<String> matchLocations = const []})

Properties

badge int?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
itemBuilder Widget Function(BuildContext context, bool active)?
final
label String
final
location String
final
matchLocations List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited