NavItemBuilder class

Constructors

Properties

activeBackgroundColor Color?
getter/setter pair
activeColor Color?
getter/setter pair
activeGradient Gradient?
getter/setter pair
backgroundColor Color?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inactiveBackgroundColor Color?
getter/setter pair
inactiveColor Color?
getter/setter pair
items List<AppStackMenuItem>
getter/setter pair
ref ↔ WidgetRef
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, int index, bool active) Widget
Called when the tab item is build.
fixed() bool
Whether the convex shape is fixed center or positioned according to selection.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited