FBField class

Constructors

FBField({required String id, String? label, FBFieldTypes type = FBFieldTypes.text, dynamic initialValue, String? validate(String?)?, Widget? icon, String? placeholder, String? helpText, dynamic maxValue, dynamic minValue, List<FBFieldOption>? options, int? lines = 1, bool optional = false, int? maxLength, int? minLength, Widget? expandedHelp, TextInputType? keyboardType = TextInputType.text, bool disabled = false, bool conditionalBy(Map<String, dynamic>)?})

Properties

conditionalBy bool Function(Map<String, dynamic>)?
final
disabled bool
final
expandedHelp Widget?
final
hashCode int
The hash code for this object.
no setterinherited
helpText String?
final
icon Widget?
final
id String
final
initialValue → dynamic
final
keyboardType TextInputType?
final
label String?
final
lines int?
final
maxLength int?
final
maxValue → dynamic
final
minLength int?
final
minValue → dynamic
final
optional bool
final
options List<FBFieldOption>?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FBFieldTypes
final
validate String? Function(String?)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited