FBuilder class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FBuilder
Constructors
-
FBuilder({Key? key, required List<
FBField> fields, required dynamic onSubmit(Map<String, dynamic> values), dynamic onChanged(Map<String, dynamic> values)?, required dynamic onCancel(), FBButton? submitButton, FBButton? cancelButton, bool showCancelButton = true, bool showSubmitButton = true, bool showDeleteButton = false, FBButton? deleteButton, String? title, Locale? locale, bool isDense = false, InputDecoration? inputDecoration, bool disabled = false}) -
const
Properties
- cancelButton → FBButton?
-
final
- deleteButton → FBButton?
-
final
- disabled → bool
-
final
-
fields
→ List<
FBField> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDecoration → InputDecoration?
-
final
- isDense → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → Locale?
-
final
- onCancel → dynamic Function()
-
final
-
onChanged
→ dynamic Function(Map<
String, dynamic> values)? -
final
-
onSubmit
→ dynamic Function(Map<
String, dynamic> values) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCancelButton → bool
-
final
- showDeleteButton → bool
-
final
- showSubmitButton → bool
-
final
- submitButton → FBButton?
-
final
- title → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited