NetsCoreProvider class

Riverpod StateNotifier that manages persistent app-level key-value data.

Automatically loads state from StorageService on construction and persists changes back to secure storage on every mutation.

Inheritance

Constructors

NetsCoreProvider(Ref ref, [NetsCoreState state = _initial])

Properties

debugState NetsCoreState
A development-only way to access state outside of StateNotifier.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
If a listener has been added using addListener and hasn't been removed yet.
no setterinherited
mounted bool
Whether dispose was called or not.
no setterinherited
onError ↔ ErrorListener?
A callback for error reporting if one of the listeners added with addListener throws.
getter/setter pairinherited
ref → Ref
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state NetsCoreState
The current "state" of this StateNotifier.
getter/setter pairinherited
storageService StorageService
getter/setter pair
stream Stream<NetsCoreState>
A broadcast stream representation of a StateNotifier.
no setterinherited

Methods

addListener(Listener<NetsCoreState> listener, {bool fireImmediately = true}) → RemoveListener
Subscribes to this object.
inherited
clearData() → void
Clears all entries from the state data map and persists the empty state.
dispose() → void
Frees all the resources associated with this object.
inherited
loadFromStorage() Future<void>
Loads the previously persisted NetsCoreState from secure storage and updates state accordingly.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeItem(String key) → void
Removes the entry for key from the state data map.
saveState() → void
Persists the current state to secure storage.
setItem(String key, dynamic value, {bool saveKey = true}) → void
Stores value under key in the state data map.
toString() String
A string representation of this object.
inherited
updateShouldNotify(NetsCoreState old, NetsCoreState current) bool
Whether to notify listeners or not when state changes
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited