clearData method
void
clearData()
Clears all entries from the state data map and persists the empty state.
Implementation
void clearData() {
state = state.copyWith(data: {});
saveState();
}
Clears all entries from the state data map and persists the empty state.
void clearData() {
state = state.copyWith(data: {});
saveState();
}