removeItem method
Removes the entry for key from the state data map.
Implementation
void removeItem(String key) {
state = state.copyWith(
data: {
...state.data,
}..remove(key));
saveState();
}
Removes the entry for key from the state data map.
void removeItem(String key) {
state = state.copyWith(
data: {
...state.data,
}..remove(key));
saveState();
}