BaseUrl class

Represents a named URL segment in a hierarchical URL tree.

Constructors

BaseUrl({required String name, required String path, List<BaseUrl> items = const []})
Creates a BaseUrl with the given name and path.

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<BaseUrl>
Nested URL segments under this one.
getter/setter pair
name String
The logical name used to identify this URL segment (e.g. 'auth').
getter/setter pair
path String
The URL path fragment (e.g. 'auth/').
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited