NotificationService class

Holds the result state of initializeLocalNotifications.

Constructors

NotificationService({bool? initialized, bool? permissionGranted, bool didNotificationLaunchApp = false, String? launchPayload})

Properties

didNotificationLaunchApp bool
true if the app was launched by tapping a notification.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialized bool?
Whether the notification plugin was successfully initialized.
getter/setter pair
launchPayload String?
The payload from the notification that launched the app, if any.
getter/setter pair
permissionGranted bool?
Whether the user granted notification permissions.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited