StorageItem class

A single key-value pair stored in secure storage.

Constructors

StorageItem(String key, String value)
Creates a StorageItem with a key and its associated value.

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The storage key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The stored value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited