utils/device_utils library
Classes
- DeviceIdentifier
- Represents a registered device with its hardware, OS, and token information.
- DeviceIdentifierUtil
- Utility class that holds and exposes the current device's DeviceIdentifier as a set of static convenience getters and setters.