DeviceIdentifierUtil class
Utility class that holds and exposes the current device's DeviceIdentifier as a set of static convenience getters and setters.
Constructors
Properties
- deviceInfoPlugin → DeviceInfoPlugin
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getIdentifier(
String? appVersion) → Future< DeviceIdentifier> - Collects device information and returns a populated DeviceIdentifier.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- deviceActive → bool
-
no setter
- deviceAppVersion → String?
-
no setter
- deviceCreated → DateTime?
-
no setter
- deviceId → int?
-
no setter
- deviceIdentifier ↔ DeviceIdentifier?
-
The singleton DeviceIdentifier for the running device.
getter/setter pair
-
deviceJson
→ Map<
String, dynamic> -
no setter
- deviceLastLogin → DateTime?
-
no setter
- deviceName → String
-
The device name, or an empty string if not set.
no setter
- deviceOs → String
-
The device OS string, or an empty string if not set.
no setter
- deviceOsVersion → String?
-
no setter
- deviceToken → String?
-
no setter
- deviceUpdated → DateTime?
-
no setter
- deviceUuid → String?
-
no setter
- firebaseToken → String?
-
no setter
Static Methods
-
clearDeviceIdentifier(
) → void -
setDeviceActive(
bool active) → void -
setDeviceAppVersion(
String appVersion) → void -
setDeviceCreated(
DateTime created) → void -
setDeviceId(
int id) → void -
setDeviceIdentifier(
DeviceIdentifier deviceIdentifier) → void -
setDeviceJson(
Map< String, dynamic> json) → void -
setDeviceLastLogin(
DateTime lastLogin) → void -
setDeviceName(
String name) → void -
setDeviceOs(
String os) → void -
setDeviceOsVersion(
String osVersion) → void -
setDeviceToken(
String deviceToken) → void -
setDeviceUpdated(
DateTime updated) → void -
setDeviceUuid(
String uuid) → void -
setFirebaseToken(
String firebaseToken) → void