deviceOs property
String
get
deviceOs
The device OS string, or an empty string if not set.
Implementation
static String get deviceOs => deviceIdentifier?.os ?? '';
The device OS string, or an empty string if not set.
static String get deviceOs => deviceIdentifier?.os ?? '';