components/lists/options_list_item library

Classes

OptionListItem
A configurable list-row widget that can render as a plain tile, a switch, a radio button, or a checkbox depending on type.

Enums

OptionListType
Visual style variants for an OptionListItem.