AppLocalizationsEn class
The translations for English (en).
- Inheritance
-
- Object
- AppLocalizations
- AppLocalizationsEn
Constructors
- AppLocalizationsEn([String locale = 'en'])
Properties
- cancel → String
-
No description provided for @cancel.
no setteroverride
- continueNext → String
-
No description provided for @continueNext.
no setteroverride
- country → String
-
No description provided for @country.
no setteroverride
- description → String
-
No description provided for @description.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- localeName → String
-
finalinherited
- name → String
-
No description provided for @name.
no setteroverride
- no → String
-
No description provided for @no.
no setteroverride
- picture → String
-
No description provided for @picture.
no setteroverride
- picturePreview → String
-
No description provided for @picturePreview.
no setteroverride
- requiredField → String
-
No description provided for @requiredField.
no setteroverride
- retakePicture → String
-
No description provided for @retakePicture.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submit → String
-
No description provided for @submit.
no setteroverride
- yes → String
-
No description provided for @yes.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited