NetsCoreState class abstract
Immutable state for the NetsCoreProvider.
Holds generic key-value data persisted to secure storage, sync metadata,
and flags that control which keys survive across sessions.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
NetsCoreState({@Default.new(false) bool initialized, @Default.new(false) bool synced, DateTime? lastSync, @Default.new(0.1) double appVersion, @Default.new(false) bool appRegistered, @Default.new(<String, dynamic>{}) Map<
String, dynamic> data, @Default.new(<String, bool>{}) Map<String, bool> saveKeys}) -
constfactory
-
NetsCoreState.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appRegistered → bool
-
no setterinherited
- appVersion → double
-
no setterinherited
-
copyWith
→ $NetsCoreStateCopyWith<
NetsCoreState> -
Create a copy of NetsCoreState
with the given fields replaced by the non-null parameter values.
no setterinherited
-
data
→ Map<
String, dynamic> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
no setterinherited
- lastSync → DateTime?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
saveKeys
→ Map<
String, bool> -
no setterinherited
- synced → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_NetsCoreState value)) → TResult -
Available on NetsCoreState, provided by the NetsCoreStatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_NetsCoreState value)?) → TResult? -
Available on NetsCoreState, provided by the NetsCoreStatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_NetsCoreState value)?, {required TResult orElse()}) → TResult -
Available on NetsCoreState, provided by the NetsCoreStatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool initialized, bool synced, DateTime? lastSync, double appVersion, bool appRegistered, Map< String, dynamic> data, Map<String, bool> saveKeys)?, {required TResult orElse()}) → TResult -
Available on NetsCoreState, provided by the NetsCoreStatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this NetsCoreState to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool initialized, bool synced, DateTime? lastSync, double appVersion, bool appRegistered, Map< String, dynamic> data, Map<String, bool> saveKeys)) → TResult -
Available on NetsCoreState, provided by the NetsCoreStatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool initialized, bool synced, DateTime? lastSync, double appVersion, bool appRegistered, Map< String, dynamic> data, Map<String, bool> saveKeys)?) → TResult? -
Available on NetsCoreState, provided by the NetsCoreStatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited