OnDownloadProgressCallback typedef

OnDownloadProgressCallback = void Function(int receivedBytes, int totalBytes)

Callback invoked during file download to report progress.

receivedBytes is the number of bytes received so far. totalBytes is the total size of the file being downloaded.

Implementation

typedef OnDownloadProgressCallback = void Function(
    int receivedBytes, int totalBytes);