OnUploadProgressCallback typedef
Callback invoked during file upload to report progress.
sentBytes is the number of bytes sent so far.
totalBytes is the total size of the file being uploaded.
Implementation
typedef OnUploadProgressCallback = void Function(int sentBytes, int totalBytes);