NotificationAction class
An inline action button that can appear on a notification.
Constructors
- NotificationAction(String id, String title)
-
Creates a NotificationAction with
idandtitle.
Properties
- color ↔ Color?
-
Optional colour for the action title.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
Unique action identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
Label shown on the action button.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited