NotificationChannel class
Defines an Android notification channel used to group and style notifications.
Constructors
- NotificationChannel({required String id, required String name, String? description, String? icon, Color? color, String? ticker})
- Creates a NotificationChannel.
Properties
- color ↔ Color?
-
Optional accent colour for notifications on this channel.
getter/setter pair
- description ↔ String?
-
Optional description shown in device settings.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ String?
-
Optional drawable icon name (without extension).
getter/setter pair
- id ↔ String
-
Unique channel identifier.
getter/setter pair
- name ↔ String
-
Human-readable channel name shown in device settings.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticker ↔ String?
-
Optional ticker text for accessibility.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited