NotificationMessage class
Represents a notification to be displayed to the user.
Constructors
-
NotificationMessage({required int id, required String title, required String body, String? payload, List<
NotificationAction> ? actions}) - Creates a NotificationMessage.
Properties
-
actions
↔ List<
NotificationAction> ? -
Optional list of inline action buttons.
getter/setter pair
- body ↔ String
-
Notification body text.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
Unique notification identifier.
getter/setter pair
- payload ↔ String?
-
Optional string payload delivered when the user taps the notification.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
Short notification title.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited