didReceiveLocalNotificationStream top-level property
Stream of NotificationMessage objects broadcast when a local notification
is received while the app is in the foreground.
Since the plugin is initialised in main, streams are the recommended
way to propagate notification events to the UI.
Implementation
final StreamController<NotificationMessage> didReceiveLocalNotificationStream =
StreamController<NotificationMessage>.broadcast();