DeviceIdentifier class
Represents a registered device with its hardware, OS, and token information.
Constructors
- DeviceIdentifier({required String name, required String os, String? uuid, String? osVersion, String? appVersion, String? deviceToken, String? firebaseToken, bool active = true, int? id, DateTime? lastLogin, DateTime? created, DateTime? updated, String? ip})
- Creates a DeviceIdentifier.
-
DeviceIdentifier.fromJson(Map<
String, dynamic> json) -
Deserialises a DeviceIdentifier from a JSON Map.
factory
Properties
- active ↔ bool
-
Whether the device is considered active.
getter/setter pair
- appVersion ↔ String?
-
Application version string.
getter/setter pair
- created ↔ DateTime?
-
Timestamps for last login, creation, and last update.
getter/setter pair
- deviceToken ↔ String?
-
Platform push notification token.
getter/setter pair
- firebaseToken ↔ String?
-
Firebase Cloud Messaging token.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
Server-assigned identifier.
getter/setter pair
- ip ↔ String?
-
Device IP address.
getter/setter pair
- lastLogin ↔ DateTime?
-
Timestamps for last login, creation, and last update.
getter/setter pair
- name ↔ String
-
Human-readable device name (brand, model, etc.).
getter/setter pair
- os ↔ String
-
Operating system name and version string.
getter/setter pair
- osVersion ↔ String?
-
OS version string.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updated ↔ DateTime?
-
Timestamps for last login, creation, and last update.
getter/setter pair
- uuid ↔ String?
-
Unique device identifier (UUID / vendor identifier).
getter/setter pair
Methods
-
copyWith(
{String? name, String? os, String? uuid, String? osVersion, String? appVersion, String? deviceToken, String? firebaseToken, bool? active, int? id, DateTime? lastLogin, DateTime? created, DateTime? updated, String? ip}) → DeviceIdentifier - Returns a copy of this DeviceIdentifier with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this DeviceIdentifier to a JSON Map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited